CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
75 lines
2.0 KiB
C++
75 lines
2.0 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
|
|
static __global__ void write_integer(int* memory, int value) { *memory = value; }
|
|
|
|
HIP_TEST_CASE(Unit_hipMallocHost_Positive) {
|
|
int* host_memory = nullptr;
|
|
|
|
HIP_CHECK(hipMallocHost(reinterpret_cast<void**>(&host_memory), sizeof(int)));
|
|
REQUIRE(host_memory != nullptr);
|
|
HIP_CHECK(hipHostFree(host_memory));
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipMallocHost_DataValidation) {
|
|
int validation_number = 10;
|
|
int* host_memory = nullptr;
|
|
hipEvent_t event = nullptr;
|
|
|
|
HIP_CHECK(hipMallocHost(reinterpret_cast<void**>(&host_memory), sizeof(int)));
|
|
|
|
write_integer<<<1, 1>>>(host_memory, validation_number);
|
|
|
|
SECTION("device sync") { HIP_CHECK(hipDeviceSynchronize()); }
|
|
|
|
SECTION("event sync") {
|
|
HIP_CHECK(hipEventCreateWithFlags(&event, 0));
|
|
HIP_CHECK(hipEventRecord(event, nullptr));
|
|
HIP_CHECK(hipEventSynchronize(event));
|
|
}
|
|
|
|
SECTION("stream sync") { HIP_CHECK(hipStreamSynchronize(nullptr)); }
|
|
|
|
REQUIRE(*host_memory == validation_number);
|
|
|
|
if (event != nullptr) {
|
|
HIP_CHECK(hipEventDestroy(event));
|
|
}
|
|
|
|
HIP_CHECK(hipHostFree(host_memory));
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipMallocHost_Negative) {
|
|
int* host_memory = nullptr;
|
|
|
|
SECTION("host memory is nullptr") {
|
|
HIP_CHECK_ERROR(hipMallocHost(nullptr, sizeof(int)), hipErrorInvalidValue);
|
|
}
|
|
|
|
SECTION("size is negative") {
|
|
HIP_CHECK_ERROR(hipMallocHost(reinterpret_cast<void**>(&host_memory), -1), hipErrorOutOfMemory);
|
|
}
|
|
}
|
|
|
|
HIP_TEST_CASE(Unit_hipMallocHost_Capture) {
|
|
int* host_memory = nullptr;
|
|
|
|
hipError_t capture_error = hipSuccess;
|
|
constexpr bool kRelaxedModeAllowed = true;
|
|
|
|
BEGIN_CAPTURE_SYNC(capture_error, kRelaxedModeAllowed);
|
|
HIP_CHECK_ERROR(hipMallocHost(reinterpret_cast<void**>(&host_memory), sizeof(int)),
|
|
capture_error);
|
|
END_CAPTURE_SYNC(capture_error);
|
|
|
|
if (capture_error == hipSuccess) {
|
|
REQUIRE(host_memory != nullptr);
|
|
HIP_CHECK(hipHostFree(host_memory));
|
|
}
|
|
}
|